from .. import ImapImporter, MboxImporter
from getpass import getpass


def imap_importer(google_group, imap_server, email, password=None, query='ALL', client_id=None, client_secret=None, **kwargs):
    """
    Import an IMAP mailbox to a Google Group

     __                        ______              
    |__|.--------.---.-.-----.|__    |.-----.-----.
    |  ||        |  _  |  _  ||    __||  _  |  _  |
    |__||__|__|__|___._|   __||______||___  |___  |
                       |__|           |_____|_____|

    If `password` is not provided will prompt for it
    `client_id` and `client_secret` are just needed the first time. The authorization file `.credentials` will be created and reused
    Default query is 'ALL'. Examples: 'SEEN', 'UNSEEN'. See https://github.com/ikvk/imap_tools/blob/master/README.rst#search-criteria for more filters

    Examples
    - Import everything from my IMAP server
    `$ imap2gg example@googlegroups.com myimapserver.com example@myimapserver.com aPassword --client_id=11111111-asjdhasjdkhasdjkhasjkh12.apps.googleusercontent.com --client_secret=4JHsadhj23jhasdj`

    - Import everything from a gmail account
    `$ imap2gg another@googlegroups.com imap.gmail.com example@gmail.com aPassword --client_id=11111111-asjdhasjdkhasdjkhasjkh12.apps.googleusercontent.com --client_secret=4JHsadhj23jhasdj`

    - Import just unseen emails:
    `$ imap2gg another@googlegroups.com imap.gmail.com example@gmail.com aPassword --query='UNSEEN'

    Errors are logged to stdout and embeded into `error.mbox` file.

    Issues and contributions to https://github.com/XaviTorello/mail2gg
    """

    if not password:
        password = getpass('Enter password: ')
    ImapImporter(
        group_id=google_group,
        server=imap_server,
        email=email,
        password=password,
        query=query,
        client_id=client_id,
        client_secret=client_secret,
        **kwargs,
    )


def mbox_importer(google_group, mbox, client_id=None, client_secret=None, **kwargs):
    """
    Import an mbox file to a Google Group

               __                 ______              
    .--------.|  |--.-----.--.--.|__    |.-----.-----.
    |        ||  _  |  _  |_   _||    __||  _  |  _  |
    |__|__|__||_____|_____|__.__||______||___  |___  |
                                         |_____|_____|

    `client_id` and `client_secret` are just needed the first time. The authorization file `.credentials` will be created and reused

    Examples
    - Import everything from mailbox.mbox to example@googlegroups.com
    `$ mbox2gg example@googlegroups.com mailbox.mbox --client_id=11111111-asjdhasjdkhasdjkhasjkh12.apps.googleusercontent.com --client_secret=4JHsadhj23jhasdj`

    Errors are logged to stdout and embeded into `error.mbox` file.

    Issues and contributions to https://github.com/XaviTorello/mail2gg
    """

    MboxImporter(
        group_id=google_group,
        mbox=mbox,
        client_id=client_id,
        client_secret=client_secret,
        **kwargs,
    )



from setuptools import setup, find_packages
from os import path
import pkg_resources

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

with open(path.join(here, 'requirements.txt')) as requirements_txt:
    install_requires = [
        str(requirement)
        for requirement
        in pkg_resources.parse_requirements(requirements_txt)
    ]

setup(
    name='mail2gg',
    version='0.1.4',
    packages=find_packages(),
    description='Import mail to Google Groups using an IMAP account or mbox file',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/XaviTorello/mail2gg',
    download_url='https://github.com/XaviTorello/mail2gg/archive/master.zip',
    project_urls={
        'Bug Reports': 'https://github.com/XaviTorello/mail2gg/issues',
        'Source': 'https://github.com/XaviTorello/mail2gg',
        'Download': 'https://github.com/XaviTorello/mail2gg/archive/master.zip',
    },
    author='Xavi Torelló',
    author_email='info@xaviertorello.cat',
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)',

        'Environment :: Console',
        'Topic :: Communications :: Email',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',

        'Operating System :: POSIX',
        'Operating System :: POSIX :: Linux',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',

        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3',
    ],
    keywords='mail importer googlegroups google groups imap mbox migrate',

    python_requires='>=3.5, <4',
    install_requires=install_requires,

    entry_points={
        'console_scripts': [
            'imap2gg = mail2gg.cli:execute_imap_importer',
            'mbox2gg = mail2gg.cli:execute_mbox_importer',
        ]
    }
)
